@@ -4,9 +4,6 @@ require 'rspec-system-serverspec/helpers'
 
 include RSpecSystemPuppet::Helpers
 
-include Serverspec::Helper::RSpecSystem
-include Serverspec::Helper::DetectOS
-
 RSpec.configure do |c|
   # Project root
   proj_root = File.expand_path(File.join(File.dirname(__FILE__), '..'))
